@@ -176,7 +176,7 @@ class User(UserCompact):
     website: Optional[str]
     scores_pinned_count: int
     nominated_beatmapset_count: int
-    rank_highest: RankHighest
+    rank_highest: Optional[RankHighest]
 
     def expand(self) -> User:
         # we're already expanded, no need to waste an api call
@@ -1188,7 +1188,8 @@ class Matches(Model):
 class MatchGame(Model):
     id: int
     start_time: Datetime
-    end_time: Datetime
+    # null for in-progress matches.
+    end_time: Optional[Datetime]
     mode: GameMode
     mode_int: int
     scoring_type: ScoringType
