@@ -2,7 +2,7 @@ from datetime import datetime
 from unittest import TestCase
 
 from ossapi import (RankingType, BeatmapsetEventType, AccessDeniedError,
-    InsufficientScopeError, Mod, GameMode, ForumPoll)
+    InsufficientScopeError, Mod, GameMode, ForumPoll, RoomSearchType)
 
 from tests import (
     TestCaseAuthorizationCode, TestCaseDevServer, UNIT_TEST_MESSAGE,
@@ -26,7 +26,7 @@ class TestSpotlights(TestCase):
 
 class TestUserBeatmaps(TestCase):
     def test_deserialize(self):
-        api.user_beatmaps(user_id=12092800, type_="most_played")
+        api.user_beatmaps(user_id=12092800, type="most_played")
 
 class TestUserKudosu(TestCase):
     def test_deserialize(self):
@@ -110,7 +110,7 @@ class TestUser(TestCase):
 
 class TestMe(TestCase):
     def test_insufficient_scope(self):
-        # client credentials api can't request `Scope.IDENTIFY` and so can't
+        # client credentials grant can't request `Scope.IDENTIFY` and so can't
         # access /me
         self.assertRaises(InsufficientScopeError, api.get_me)
 
@@ -128,7 +128,7 @@ class TestChangelogListing(TestCase):
 
 class TestChangelogLookup(TestCase):
     def test_deserialize(self):
-        api.changelog_lookup("lazer")
+        api.changelog_build_lookup("lazer")
 
 class TestForumTopic(TestCase):
     def test_deserialize(self):
@@ -192,6 +192,20 @@ class TestFriends(TestCase):
     def test_access_denied(self):
         self.assertRaises(InsufficientScopeError, api.friends)
 
+class TestRoom(TestCase):
+    def test_deserialize(self):
+        # https://osu.ppy.sh/multiplayer/rooms/257524
+        api.room(257524)
+
+class TestMatches(TestCase):
+    def test_deserialize(self):
+        api.matches()
+
+class TestMatch(TestCase):
+    def test_deserialize(self):
+        # https://osu.ppy.sh/community/matches/97947404, tournament match
+        api.match(97947404)
+
 
 # ======================
 # api_full test cases
@@ -210,6 +224,18 @@ class TestFriendsAuth(TestCaseAuthorizationCode):
     def test_deserialize(self):
         api_full.friends()
 
+class TestRoomLeaderboard(TestCaseAuthorizationCode):
+    def test_deserialize(self):
+        # https://osu.ppy.sh/multiplayer/rooms/232594
+        api_full.room_leaderboard(232594)
+
+class TestRooms(TestCaseAuthorizationCode):
+    def test_deserialize(self):
+        api_full.rooms()
+        # not really sure what OWNED means here, owned by the resource owner?
+        # but when I test it against myself I don't think it returns my hosted
+        # rooms...
+        api_full.rooms(RoomSearchType.OWNED)
 
 
 # =====================
@@ -226,7 +252,7 @@ class TestForum(TestCaseDevServer):
         # 2d430a2/config/osu.php#L107.
 
         # create and edit a topic
-        response = api_dev.forum_create_topic(UNIT_TEST_MESSAGE, 85,
+        response = api_dev.forum_create_topic(85, UNIT_TEST_MESSAGE,
             UNIT_TEST_MESSAGE)
         topic_id = response.topic.id
         api_dev.forum_edit_topic(topic_id,
